@@ -85,15 +85,11 @@ class Project(object):
         """Create the SIB project"""
 
         try:
-            try:
-                import django
-                import djangoldp
-            except ModuleNotFoundError:
-                # install djangoldp (and gets the right version of django as dependency)
-                cmd = ['pip', 'install', 'djangoldp']
-                if not self.is_venv():
-                    cmd.append('--user')
-                subprocess.run(cmd).check_returncode()
+            # install djangoldp (and gets the right version of django as dependency)
+            cmd = ['pip', 'install', '--upgrade', '--no-cache', 'djangoldp']
+            if not self.is_venv():
+                cmd.append('--user')
+            subprocess.run(cmd).check_returncode()
 
             # force installation of psycopg for prd
             if production:
@@ -105,6 +101,12 @@ class Project(object):
                         cmd.append('--user')
                     subprocess.run(cmd).check_returncode()
 
+            # install django-cookies-samesite
+            cmd = ['pip', 'install', 'django-cookies-samesite']
+            if not self.is_venv():
+                cmd.append('--user')
+            subprocess.run(cmd).check_returncode()
+
             try:
                 os.mkdir(self.folder)
             except FileExistsError:
